PullToRefreshDefaultDelegate class

Inheritance
Implementers

Constructors

PullToRefreshDefaultDelegate({required TickerProvider vsync, SpringDescription? spring})

Properties

distanceFraction Animation<double>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spring SpringDescription
getter/setter pair

Methods

animateToHidden() TickerFuture
override
animateToThreshold() TickerFuture
override
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapTo(double targetValue) → void
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultSpring SpringDescription
final