endFraction property
End of the progress interval that will be scaled to the proper range.
Defaults to 1.0.
Implementation
final double endFraction;
End of the progress interval that will be scaled to the proper range.
Defaults to 1.0.
final double endFraction;