PullToRefreshStates mixin

Mixin applications

Properties

adjustedDistancePulled double
no setter
distanceFraction double
Distance percentage towards the refresh threshold.
no setter
distancePulled double
no setter
enabled bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isAnimating bool
Whether the indicator is currently animating to the threshold offset, or back to the hidden offset.
no setter
isRefreshing bool
no setter
progress double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold double
no setter
verticalOffset double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited