isAnimating property
bool
get
isAnimating
Whether the indicator is currently animating to the threshold offset, or back to the hidden offset.
Implementation
bool get isAnimating;
Whether the indicator is currently animating to the threshold offset, or back to the hidden offset.
bool get isAnimating;