EnergyColors class abstract final

Represents the result of energy color generation, containing end and middle colors.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

withAccentsArgb(int baseColor, int primaryColor, int secondaryColor, int tertiaryColor, int surfaceColor, bool isBaseline, [BaseColorRole? baseColorRole]) → (int, int)
Generates Energy Colors (End, Middle, Base) using Material Theme inputs.
withAccentsHct(Hct baseColor, Hct primaryColor, Hct secondaryColor, Hct tertiaryColor, Hct surfaceColor, bool isBaseline, [BaseColorRole? baseColorRole]) → (Hct, Hct)
Generates Energy Colors (End, Middle, Base) using Material Theme inputs.
withHueRotationsArgb(int baseColor, bool isDark, double rotationDirection, double endHueRotation, double middleHueRotation) → (int, int)
Generates energy colors based on hue rotations from a base color.
withHueRotationsHct(Hct baseColor, bool isDark, double rotationDirection, double endHueRotation, double middleHueRotation) → (Hct, Hct)
Generates energy colors based on hue rotations from a base color.
withHueValuesArgb(int baseColor, bool isDark, double endHue, double middleHue) → (int, int)
Generates energy colors based on a base color.
withHueValuesHct(Hct baseColor, bool isDark, double endHue, double middleHue) → (Hct, Hct)
Generates energy colors based on a base color.