Hct class final
HCT, hue, chroma, and tone. A color system that provides a perceptually accurate color measurement system that can also accurately render what colors will appear as in different lighting environments.
Constructors
Properties
Methods
-
copyWith(
{double? hue, double? chroma, double? tone}) → Hct -
inViewingConditions(
ViewingConditions viewingConditions) → Hct -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toInt(
) → int -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override