Variant enum

Themes for Dynamic Color.

Inheritance
Available extensions

Values

monochrome → const Variant

Monochrome.

neutral → const Variant

Neutral.

tonalSpot → const Variant

Tonal spot.

vibrant → const Variant

Vibrant.

expressive → const Variant

Expressive.

fidelity → const Variant

Fidelity.

content → const Variant

Content.

rainbow → const Variant

Rainbow.

fruitSalad → const Variant

Fruit salad.

cmf → const Variant

CMF.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Variant>
A constant List of the values in this enum, in order of their declaration.