Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
calculateScaleFactor(List<RoundedPolygon> indicatorPolygons, {bool approximate = true})
→ double
-
-
defaultForEachPolygon(RoundedPolygon polygon)
→ RoundedPolygon
-
-
generateMorphSequence({required List<RoundedPolygon> polygons, required bool circularSequence, LoadingIndicatorForEachPolygon forEachPolygon = defaultForEachPolygon})
→ Iterable<Morph>
-
-
paintPathWithTransform({required Canvas canvas, required Size size, required Path path, double scale = 1.0, double rotation = 0.0, Matrix4? matrix, required Paint paint})
→ void
-
-
transformPath({required Size size, required Path path, double scale = 1.0, double rotation = 0.0, Matrix4? matrix})
→ Path
-
-
updateMorphSequence({List<Morph>? morphSequence, required List<RoundedPolygon> polygons, required bool circularSequence, LoadingIndicatorForEachPolygon forEachPolygon = defaultForEachPolygon})
→ List<Morph>
-