PullToRefreshCollapsingDelegate class
- Inheritance
-
- Object
- PullToRefreshDelegate
- PullToRefreshDefaultDelegate
- PullToRefreshCollapsingDelegate
Constructors
- PullToRefreshCollapsingDelegate({required TickerProvider vsync, SpringDescription? spring})
Properties
-
distanceFraction
→ Animation<
double> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layoutFraction
→ Animation<
double> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spring ↔ SpringDescription
-
getter/setter pairinherited
Methods
-
animateToHidden(
) → TickerFuture -
override
-
animateToThreshold(
) → TickerFuture -
override
-
dispose(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
snapTo(
double targetValue) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited