PullToRefreshCollapsingStates mixin
- Implemented types
- Mixin applications
Properties
- adjustedDistancePulled → double
-
no setterinherited
- distanceFraction → double
-
Distance percentage towards the refresh threshold.
no setterinherited
- distancePulled → double
-
no setterinherited
- enabled → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAnimating → bool
-
Whether the indicator is currently animating to the
threshold offset, or back to the hidden offset.
no setterinherited
- isRefreshing → bool
-
no setterinherited
- layoutFraction → double
-
no setter
- layoutHeight → double
-
no setter
- progress → double
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threshold → double
-
no setterinherited
- verticalOffset → double
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited